==> activity-center-api-1.2.10.8-20161209.073644-1-sources.jar: cn/com/duiba/activity/center/api/dto/ngame/NgameOrdersDto.java <==
package cn.com.duiba.activity.center.api.dto.ngame;

import cn.com.duiba.dcommons.enums.ItemTypeEnums;

import java.io.Serializable;
import java.util.Date;
import java.util.UUID;

/**
 * 
 * ClassName: NgameOrdersDto <br/>
 * date: 2016年12月1日 上午10:09:23 <br/>
 *
 * @version 
 * @since JDK 1.6
 */
public class NgameOrdersDto implements Serializable {
	private static final long serialVersionUID = 13124L;

	public static final String PREFIX_ORDER = "ngame-";

	public static final int StatusCreate = 0; // 创建
	public static final int StatusConsumeSuccess = 1; // 扣积分成功
	public static final int StatusSuccess = 2; // 订单完成
	public static final int StatusFail = 3; // 订单失败

	public static final int ExchangeStatusCreate = 0; // 创建
	public static final int ExchangeStatusWaitOpen = 1;// 待开奖
	public static final int ExchangeStatusWait = 2; // 待领取
	public static final int ExchangeStatusSuccess = 3; // 领奖成功
	public static final int ExchangeStatusOverdue = 4; // 未领取，过期
	public static final int ExchangeStatusFail = 5; // 领奖失败

	public static final String PrizeTypeVirtual = ItemTypeEnums.TypeVirtual.getName(); // 虚拟商品
	public static final String PrizeTypeAlipay = ItemTypeEnums.TypeAlipay.getName(); // 支付宝
	public static final String PrizeTypeQB = ItemTypeEnums.TypeQB.getName(); // QB
	public static final String PrizeTypeCoupon = ItemTypeEnums.TypeCoupon.getName(); // 优惠劵
	public static final String PrizeTypeObject = ItemTypeEnums.TypeObject.getName(); // 实物
	public static final String PrizeTypePhonebill = ItemTypeEnums.TypePhonebill.getName(); // 话费
	public static final String PrizeTypeThanks = "thanks"; // 谢谢参与
	public static final String PrizeTypeLuckBag = "lucky";//福袋lucky

	private Long id;
	private Long appId;
	private Long consumerId;
	private String partnerUserId;
	private Long operatingActivityId;
	private Long duibaNgameId;
	private String token;
	private String gameType;
	private Long itemId;
	private Long appItemId;
	private Long credits;
	private Long prizeId;
	private String prizeName;
	private String prizeType;
	private Date prizeOverdueDate;
	private String prizeFacePrice;
	private Long score;
	private Long couponId;
	private Integer orderStatus;
	private Integer exchangeStatus;
	private Long gameOrderExtraId;
	private Long mainOrderId;
	private String mainOrderNum;
	private String developerBizId;
	private String ip;
	private String error4admin;
	private String error4developer;
	private String error4consumer;
	private Date gmtCreate;
	private Date gmtModified;

	/**
	 * 
	 * Creates a new instance of NgameOrdersDto.
	 *
	 */
	public NgameOrdersDto() {

	}

	/**
	 * 
	 * Creates a new instance of NgameOrdersDto.
	 *
	 * @param id
	 */
	public NgameOrdersDto(Long id) {
		this.id = id;
		this.gmtModified = new Date();
	}

	/**
	 * 
	 * Creates a new instance of NgameOrdersDto.
	 *
	 * @param init4insert
	 */
	public NgameOrdersDto(boolean init4insert) {
		if (init4insert) {
			gmtCreate = new Date();
			gmtModified = new Date();
		}
	}

	/**
	 * 
	 * generateOrderNum:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @param id
	 * @return
	 * @since JDK 1.6
	 */
	public static synchronized String generateOrderNum(Long id) {
		return PREFIX_ORDER + id.toString();
	}

	/**
	 * 
	 * generateOrderToken:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @return
	 * @since JDK 1.6
	 */
	public static synchronized String generateOrderToken() {
		String token = UUID.randomUUID().toString();
		token = token.replaceAll("-", "");
		return token;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public Long getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(Long consumerId) {
		this.consumerId = consumerId;
	}

	public String getPartnerUserId() {
		return partnerUserId;
	}

	public void setPartnerUserId(String partnerUserId) {
		this.partnerUserId = partnerUserId;
	}

	public Long getOperatingActivityId() {
		return operatingActivityId;
	}

	public void setOperatingActivityId(Long operatingActivityId) {
		this.operatingActivityId = operatingActivityId;
	}

	public Long getDuibaNgameId() {
		return duibaNgameId;
	}

	public void setDuibaNgameId(Long duibaNgameId) {
		this.duibaNgameId = duibaNgameId;
	}

	public String getToken() {
		return token;
	}

	public void setToken(String token) {
		this.token = token;
	}

	public String getGameType() {
		return gameType;
	}

	public void setGameType(String gameType) {
		this.gameType = gameType;
	}

	public Long getItemId() {
		return itemId;
	}

	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}

	public Long getAppItemId() {
		return appItemId;
	}

	public void setAppItemId(Long appItemId) {
		this.appItemId = appItemId;
	}

	public Long getCredits() {
		return credits;
	}

	public void setCredits(Long credits) {
		this.credits = credits;
	}

	public Long getPrizeId() {
		return prizeId;
	}

	public void setPrizeId(Long prizeId) {
		this.prizeId = prizeId;
	}

	public String getPrizeName() {
		return prizeName;
	}

	public void setPrizeName(String prizeName) {
		this.prizeName = prizeName;
	}

	public String getPrizeType() {
		return prizeType;
	}

	public void setPrizeType(String prizeType) {
		this.prizeType = prizeType;
	}

	public String getPrizeFacePrice() {
		return prizeFacePrice;
	}

	public void setPrizeFacePrice(String prizeFacePrice) {
		this.prizeFacePrice = prizeFacePrice;
	}

	public Long getScore() {
		return score;
	}

	public void setScore(Long score) {
		this.score = score;
	}

	public Long getCouponId() {
		return couponId;
	}

	public void setCouponId(Long couponId) {
		this.couponId = couponId;
	}

	public Integer getExchangeStatus() {
		return exchangeStatus;
	}

	public void setExchangeStatus(Integer exchangeStatus) {
		this.exchangeStatus = exchangeStatus;
	}

	public Long getGameOrderExtraId() {
		return gameOrderExtraId;
	}

	public void setGameOrderExtraId(Long gameOrderExtraId) {
		this.gameOrderExtraId = gameOrderExtraId;
	}

	public Long getMainOrderId() {
		return mainOrderId;
	}

	public void setMainOrderId(Long mainOrderId) {
		this.mainOrderId = mainOrderId;
	}

	public String getMainOrderNum() {
		return mainOrderNum;
	}

	public void setMainOrderNum(String mainOrderNum) {
		this.mainOrderNum = mainOrderNum;
	}

	public String getDeveloperBizId() {
		return developerBizId;
	}

	public void setDeveloperBizId(String developerBizId) {
		this.developerBizId = developerBizId;
	}

	public String getIp() {
		return ip;
	}

	public void setIp(String ip) {
		this.ip = ip;
	}

	public String getError4admin() {
		return error4admin;
	}

	public void setError4admin(String error4admin) {
		if (error4admin != null && error4admin.length() > 250) {
			error4admin = error4admin.substring(0, 250);
		}
		this.error4admin = error4admin;
	}

	public String getError4developer() {
		return error4developer;
	}

	public void setError4developer(String error4developer) {
		if (error4developer != null && error4developer.length() > 250) {
			error4developer = error4developer.substring(0, 250);
		}
		this.error4developer = error4developer;
	}

	public String getError4consumer() {
		return error4consumer;
	}

	public void setError4consumer(String error4consumer) {
		if (error4consumer != null && error4consumer.length() > 250) {
			error4consumer = error4consumer.substring(0, 250);
		}
		this.error4consumer = error4consumer;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

	public Date getPrizeOverdueDate() {
		return prizeOverdueDate;
	}

	public void setPrizeOverdueDate(Date prizeOverdueDate) {
		this.prizeOverdueDate = prizeOverdueDate;
	}

	public Integer getOrderStatus() {
		return orderStatus;
	}

	public void setOrderStatus(Integer orderStatus) {
		this.orderStatus = orderStatus;
	}

}

==> activity-center-api-1.7.20-20170921.034250-1-sources.jar: cn/com/duiba/activity/center/api/dto/ngame/NgameOrdersDto.java <==
package cn.com.duiba.activity.center.api.dto.ngame;

import cn.com.duiba.dcommons.enums.ItemTypeEnums;

import java.io.Serializable;
import java.util.Date;
import java.util.UUID;

/**
 * 
 * ClassName: NgameOrdersDto <br/>
 * date: 2016年12月1日 上午10:09:23 <br/>
 *
 * @version 
 * @since JDK 1.6
 */
public class NgameOrdersDto implements Serializable {
	private static final long serialVersionUID = 13124L;

	public static final String PREFIX_ORDER = "ngame-";

	public static final int StatusCreate = 0; // 创建
	public static final int StatusConsumeSuccess = 1; // 扣积分成功
	public static final int StatusSuccess = 2; // 订单完成
	public static final int StatusFail = 3; // 订单失败

	public static final int ExchangeStatusCreate = 0; // 创建
	public static final int ExchangeStatusWaitOpen = 1;// 待开奖
	public static final int ExchangeStatusWait = 2; // 待领取
	public static final int ExchangeStatusSuccess = 3; // 领奖成功
	public static final int ExchangeStatusOverdue = 4; // 未领取，过期
	public static final int ExchangeStatusFail = 5; // 领奖失败

	public static final String PrizeTypeVirtual = ItemTypeEnums.TypeVirtual.getName(); // 虚拟商品
	public static final String PrizeTypeAlipay = ItemTypeEnums.TypeAlipay.getName(); // 支付宝
	public static final String PrizeTypeQB = ItemTypeEnums.TypeQB.getName(); // QB
	public static final String PrizeTypeCoupon = ItemTypeEnums.TypeCoupon.getName(); // 优惠劵
	public static final String PrizeTypeObject = ItemTypeEnums.TypeObject.getName(); // 实物
	public static final String PrizeTypePhonebill = ItemTypeEnums.TypePhonebill.getName(); // 话费
	public static final String PrizeTypeThanks = "thanks"; // 谢谢参与
	public static final String PrizeTypeLuckBag = "lucky";//福袋lucky

	/** 手动开奖时会选取用户中奖记录关联的游戏子订单id
	 * 	当此订单获取过即开奖品时，会导致手动开奖奖品不能更新到子订单
	 * 	遇到这种情况是会生成一条新的游戏子订单记录，但并非用户真实参与记录
	 * 	为不影响数据统计，在子订单developerBizId字段加上特殊表示符"duiba_manual_open_ngame";
	 * */
	public static final String BIZ_ID_FOR_MANAUAL_OPEN = "duiba_manual_open_ngame";

	private Long id;
	private Long appId;
	private Long consumerId;
	private String partnerUserId;
	private Long operatingActivityId;
	private Long duibaNgameId;
	private String token;
	private String gameType;
	private Long itemId;
	private Long appItemId;
	private Long credits;
	private Long prizeId;
	private String prizeName;
	private String prizeType;
	private Date prizeOverdueDate;
	private String prizeFacePrice;
	private Long score;
	private Long couponId;
	private Integer orderStatus;
	private Integer exchangeStatus;
	private Long gameOrderExtraId;
	private Long mainOrderId;
	private String mainOrderNum;
	private String developerBizId;
	private String ip;
	private String error4admin;
	private String error4developer;
	private String error4consumer;
	private Date gmtCreate;
	private Date gmtModified;

	/**
	 * 
	 * Creates a new instance of NgameOrdersDto.
	 *
	 */
	public NgameOrdersDto() {
		super();
	}

	/**
	 * 
	 * Creates a new instance of NgameOrdersDto.
	 *
	 * @param id
	 */
	public NgameOrdersDto(Long id) {
		this.id = id;
		this.gmtModified = new Date();
	}

	/**
	 * 
	 * Creates a new instance of NgameOrdersDto.
	 *
	 * @param init4insert
	 */
	public NgameOrdersDto(boolean init4insert) {
		if (init4insert) {
			gmtCreate = new Date();
			gmtModified = new Date();
		}
	}

	/**
	 * 
	 * generateOrderNum:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @param id
	 * @return
	 * @since JDK 1.6
	 */
	public static synchronized String generateOrderNum(Long id) {
		return PREFIX_ORDER + id.toString();
	}

	/**
	 * 
	 * generateOrderToken:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @return
	 * @since JDK 1.6
	 */
	public static synchronized String generateOrderToken() {
		String token = UUID.randomUUID().toString();
		token = token.replaceAll("-", "");
		return token;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public Long getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(Long consumerId) {
		this.consumerId = consumerId;
	}

	public String getPartnerUserId() {
		return partnerUserId;
	}

	public void setPartnerUserId(String partnerUserId) {
		this.partnerUserId = partnerUserId;
	}

	public Long getOperatingActivityId() {
		return operatingActivityId;
	}

	public void setOperatingActivityId(Long operatingActivityId) {
		this.operatingActivityId = operatingActivityId;
	}

	public Long getDuibaNgameId() {
		return duibaNgameId;
	}

	public void setDuibaNgameId(Long duibaNgameId) {
		this.duibaNgameId = duibaNgameId;
	}

	public String getToken() {
		return token;
	}

	public void setToken(String token) {
		this.token = token;
	}

	public String getGameType() {
		return gameType;
	}

	public void setGameType(String gameType) {
		this.gameType = gameType;
	}

	public Long getItemId() {
		return itemId;
	}

	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}

	public Long getAppItemId() {
		return appItemId;
	}

	public void setAppItemId(Long appItemId) {
		this.appItemId = appItemId;
	}

	public Long getCredits() {
		return credits;
	}

	public void setCredits(Long credits) {
		this.credits = credits;
	}

	public Long getPrizeId() {
		return prizeId;
	}

	public void setPrizeId(Long prizeId) {
		this.prizeId = prizeId;
	}

	public String getPrizeName() {
		return prizeName;
	}

	public void setPrizeName(String prizeName) {
		this.prizeName = prizeName;
	}

	public String getPrizeType() {
		return prizeType;
	}

	public void setPrizeType(String prizeType) {
		this.prizeType = prizeType;
	}

	public String getPrizeFacePrice() {
		return prizeFacePrice;
	}

	public void setPrizeFacePrice(String prizeFacePrice) {
		this.prizeFacePrice = prizeFacePrice;
	}

	public Long getScore() {
		return score;
	}

	public void setScore(Long score) {
		this.score = score;
	}

	public Long getCouponId() {
		return couponId;
	}

	public void setCouponId(Long couponId) {
		this.couponId = couponId;
	}

	public Integer getExchangeStatus() {
		return exchangeStatus;
	}

	public void setExchangeStatus(Integer exchangeStatus) {
		this.exchangeStatus = exchangeStatus;
	}

	public Long getGameOrderExtraId() {
		return gameOrderExtraId;
	}

	public void setGameOrderExtraId(Long gameOrderExtraId) {
		this.gameOrderExtraId = gameOrderExtraId;
	}

	public Long getMainOrderId() {
		return mainOrderId;
	}

	public void setMainOrderId(Long mainOrderId) {
		this.mainOrderId = mainOrderId;
	}

	public String getMainOrderNum() {
		return mainOrderNum;
	}

	public void setMainOrderNum(String mainOrderNum) {
		this.mainOrderNum = mainOrderNum;
	}

	public String getDeveloperBizId() {
		return developerBizId;
	}

	public void setDeveloperBizId(String developerBizId) {
		this.developerBizId = developerBizId;
	}

	public String getIp() {
		return ip;
	}

	public void setIp(String ip) {
		this.ip = ip;
	}

	public String getError4admin() {
		return error4admin;
	}

	public void setError4admin(String error4admin) {
		String error4adminNew=error4admin;
		if (error4admin != null && error4admin.length() > 250) {
			error4adminNew = error4admin.substring(0, 250);
		}
		this.error4admin = error4adminNew;
	}

	public String getError4developer() {
		return error4developer;
	}

	public void setError4developer(String error4developer) {
		String error4developerNew=error4developer;
		if (error4developer != null && error4developer.length() > 250) {
			error4developerNew = error4developer.substring(0, 250);
		}
		this.error4developer = error4developerNew;
	}

	public String getError4consumer() {
		return error4consumer;
	}

	public void setError4consumer(String error4consumer) {
		String error4consumerNew=error4consumer;
		if (error4consumer != null && error4consumer.length() > 250) {
			error4consumerNew = error4consumer.substring(0, 250);
		}
		this.error4consumer = error4consumerNew;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

	public Date getPrizeOverdueDate() {
		return prizeOverdueDate;
	}

	public void setPrizeOverdueDate(Date prizeOverdueDate) {
		this.prizeOverdueDate = prizeOverdueDate;
	}

	public Integer getOrderStatus() {
		return orderStatus;
	}

	public void setOrderStatus(Integer orderStatus) {
		this.orderStatus = orderStatus;
	}

}
